About
=====

**pyxnat** was originally developed at `CEA/Neurospin 
<http://www-dsv.cea.fr/en/instituts/institut-d-imagerie-biomedicale-i2bm/services/neurospin-neurospin>`_ and funded by the European project 
`IMAGEN <http://imagen-europe.com/>`_. The project was started in 2009 with
Yannick Schwartz as the main developer but has since benefited from the
help of a lot of people. We would like to give special thanks to the XNAT
team at the Washington University of St Louis, and to the people at 
Neurospin.

People
------

* Yannick Schwartz
* Jean-Baptiste Poline
* Vincent Frouin
* Alexis Barbot
* Benjamin Thyreau
* Gael Varoquaux
* Satra Ghosh
* Stephan Gerhard
* Dan Marcus
* Tim Olsen
* Deech
* Yaroslav Halchenko
* David Just
* David Gutman
* Alexandra Anghelescu
* Mark Scully
* Adam Harding
* Janis Breeze

.. note:: If we forgot anyone, do not hesitate to send an email to 
	  yannick.schwartz@cea.fr and I’ll include you in the list.

Funding
-------

* Originally funded by the European Project IMAGEN.

* PyXNAT workshop that took place at Washington University in 2011 was 
  generously funded by the `INCF <http://www.incf.org/>`_ 
  and the XNAT team:
    - http://nrg.wustl.edu/events/nrg-to-host-2011-pyxnat-workshop/
    - http://datasharing.incf.org/ni/PyXNAT_Workshop
